@@ -15,7 +15,7 @@ use Module::Loaded qw( is_loaded );
 use POSIX          qw( strftime tzset );
 use Ref::Util      qw( is_arrayref );
 
-our $VERSION = '4.3';
+our $VERSION = '4.4';
 
 # Default for Handling Parsing
 our $DateParsing     = 1;
@@ -345,10 +345,14 @@ sub parse_syslog_line {
             };
         }
     }
-    elsif( $AutoDetectKeyValues && $msg{content} =~ /\w+=\w+/ ) {
+    elsif( $AutoDetectKeyValues && $msg{content} =~ /\s[a-zA-Z\.0-9\-_]+=\S+/ ) {
         my %sdata = ();
-        while( $msg{content} =~ /(\w+)=([^\s,]+)/g ) {
+        while( $msg{content} =~ /\s\K(?>([a-zA-Z\.0-9\-_]++))=(\S+(?:\s+\S+)*?)(?=(?:\s*[,;]|$|\s+[a-zA-Z\.0-9\-_]+=))/g ) {
             my ($k,$v) = ($1,$2);
+            # Remove Trailing Brackets
+            chop($v) if $v =~ /[)\]>]$/;
+            # Remove Leading Brackets
+            $v = substr($v,1) if $v =~ /^[(\[<]/;
             if( exists $sdata{$k} ) {
                 if( is_arrayref($sdata{$k}) ) {
                     push @{ $sdata{$k} }, $v;
@@ -449,7 +453,7 @@ Parse::Syslog::Line - Simple syslog line parser
 
 =head1 VERSION
 
-version 4.3
+version 4.4
 
 =head1 SYNOPSIS
 
